@@ -1,7 +1,12 @@
+import fire
 class Cli:
     def hi(self):
         s='Hi! This is wkweb, simple yet powerful!'.center(50,'*')
         print(s)
 
 def main():
-    pass
+    cli=Cli()
+    fire.Fire(cli)
+
+if __name__ == '__main__':
+    main()
